@@ -57,7 +57,7 @@ $NAME="MoviXMaker-2";
 # Retrieve options from command line
 GetOptions (
 	    # 	    "title=s"             => \$title,
-	    "tempDir=s"           => \$options{'tmpdir'},
+	    "tmpDir=s"           => \$options{'tmpdir'},
  	    "output-file=s"       => \$destpath,
  	    "boot-label=s"        => \$options{'bootlabel'},
  	    "extra-mkisofs-options=s"     => \@extra_mkisofs_options,
@@ -94,6 +94,7 @@ if ( defined $help ) {
   exit;
 }
 
+
 # The graphical interface is to be shown
 if (!defined $options{'nogui'}) {
   # Trying to load the Gnome perl module
@@ -115,17 +116,17 @@ if (!defined $options{'nogui'}) {
     } else {
       # Will always work as Gtk2::GladeXML depends on libgtk2-perl
       # which contains Gtk2::SimpleList
-      use Gtk2::SimpleList;
+      eval "use Gtk2::SimpleList";
     }
   }
 }
 
 # MoviXMaker-2 is started in cmdline mode.
 if (defined $options{'nogui'}) {
-  print "You've choosen not to use the GUI.\n";
+  print "You are in command line mode (--noGUI).\n";
 
   if (!defined $srcpath) {
-    print STDERR "ERROR: You need to specify the *movix* directory!\n";
+    error("You need to specify the *movix* directory!");
     exit;
   }
 }
@@ -152,7 +153,7 @@ $SIG{__WARN__} = \&Carp::cluck;
 if (defined $options{'nogui'}) {
   set_options();
   get_options();
-  prepare_iso();
+  prepare_creation();
 } else {
   prepare_interface();
   main Gtk2;
@@ -253,7 +254,7 @@ sub on_button_create_released {
   $xml_root->get_widget ("cb_noaddfiles")->set_sensitive(FALSE);
   $statusbar->set_status("Proceeding...");
 
-  prepare_iso();
+  prepare_creation();
 }
 
 sub reenable {
@@ -455,7 +456,7 @@ sub set_options {
     my $orig = `echo -n \$(pwd)`;
 
     chdir $srcpath;
-    $srcpath = `echo -n \$(pwd)`;
+    $srcpath = `echo -n \$(pwd)`; # convert to absolute path
     chdir $orig;
 
     $srcpath =~ s/([^\/])$/$1\// ; # Add a trailing /
@@ -676,7 +677,7 @@ sub prepare_interface {
 
   # Filelist creation (files that will be add to the ISO image)
   $filelist =
-    Gtk2::SimpleList->new ('Filename' => 'text');
+    Gtk2::SimpleList->new ('Path to file or directory' => 'text');
 
   # Gtk2::SimpleList is derived from Gtk2::TreeView, so you can
   # do anything you'd do to a treeview.
@@ -739,6 +740,12 @@ sub create_iso {
 
   # Create temp dir and update the global variable
   $tmpfolder = create_tmp_folder();
+  if (!$tmpfolder) {
+    $diag_feedback->hide();
+    reenable();
+    return;
+  }
+
 
   unless (defined $options{'nogui'}) {
     $fbtext = $xml_root->get_widget ("fbtext");
@@ -754,13 +761,14 @@ sub create_iso {
     $statusbar->set_status("Calling mkisofs...");
   }
 
+  my $isolinux = ($movixversion =~ /^eMoviX/) ?
+    "eMoviX/boot/" : "isolinux/";
+
   ############## TAKEN FROM mkmovixiso ###########
   ##################
   ### Standard booting options, from SysLinux docs
   ### and from slackware installation CD README
   ###############
-  my $isolinux = ($movixversion =~ /^eMoviX/) ?
-    "eMoviX/boot/" : "isolinux/";
   my $bootOptions = "-no-emul-boot -boot-load-size 4 -boot-info-table ".
     "-b ${isolinux}isolinux.bin -c ${isolinux}isolinux.boot ".
       "-sort ${isolinux}iso.sort";
@@ -1058,7 +1066,7 @@ sub get_movix_options {
   }
 }
 
-sub prepare_iso {
+sub prepare_creation {
   if (!defined $options{'nogui'}) {
     $destpath = $destination->get_full_path(0);
     $srcpath = $srcdir->get_full_path(0);
@@ -1078,58 +1086,61 @@ sub prepare_iso {
     } else {
       $statusbar->set_status("Specify a dir and destination file!");
       reenable();
-    }
-  } else {
-    if (!$movixversion) {
-      if (defined $options{'nogui'}) {
-	print "$srcpath is not a [e]MoviX[] directory!";
-	exit;
-      } else {
-	$statusbar->set_status("That's not a [e]MoviX[] dir!");
-	reenable();
-      }
-    } else {
-      # Now that we know that it's a valid *MoviX* path, let's detect
-      # what's available.
-      get_movix_options();
-
-      if (defined $options{'nogui'}) {
-	create_iso() if (defined $srcpath);
-      } else {
-	# Update the interface with avail. options
-	update_options();
-
-	# Did the user toggled the "Do not customize disc image" checkbox ?
-	if ($xml_root->get_widget ("cb_nocustomize")->get_active
-	    and $xml_root->get_widget ("cb_noaddfiles")->get_active) {
-	  # Directly creating the image, no customization
-	  create_iso() if (defined $srcpath);
-
-	  # User choose only to customize
-	} elsif ($xml_root->get_widget ("cb_noaddfiles")->get_active) {
-	  $xml_root->get_widget ("btn_customize_next")->hide;
-	  $xml_root->get_widget ("btn_customize_ok")->show;
-	  $xml_root->get_widget ("diag_customize")->show()
-	    if (defined $srcpath);
-
-	  # User choose only to add files
-	} elsif ($xml_root->get_widget ("cb_nocustomize")->get_active) {
-	  $xml_root->get_widget ("btn_addfiles_previous")->hide;
-	  $xml_root->get_widget ("diag_addfiles")->show()
-	    if (defined $srcpath);
-
-	  # User choose to customize disc image and add files
-	} else {
-	  # Let's choose the options
-	  $xml_root->get_widget ("btn_customize_ok")->hide;
-	  $xml_root->get_widget ("btn_customize_next")->show;
-	  $xml_root->get_widget ("btn_addfiles_previous")->show;
-	  $xml_root->get_widget ("diag_customize")->show()
-	    if (defined $srcpath);
-	}
-      }
+      return;
     }
   }
+
+  if (!$movixversion) {
+    if (defined $options{'nogui'}) {
+      print "$srcpath is not a [e]MoviX[] directory!\n".
+	"Please contact me if you believe it is.\n";
+      exit;
+    } else {
+      $statusbar->set_status("That's not a [e]MoviX[] dir!");
+      reenable();
+      return;
+    }
+  }
+
+  # Now that we know that it's a valid *MoviX* path, let's detect
+  # what's available.
+  get_movix_options();
+
+  # From the cmdline, we go directly to ISO creation.
+  if (defined $options{'nogui'}) {
+    create_iso();
+    return;
+  }
+
+  # Update the interface with avail. options
+  update_options();
+
+  # Did the user toggled the "Do not customize disc image" checkbox ?
+  if ($xml_root->get_widget ("cb_nocustomize")->get_active
+      and $xml_root->get_widget ("cb_noaddfiles")->get_active) {
+    # Directly creating the image, no customization
+    create_iso();
+
+    # User choose only to customize
+  } elsif ($xml_root->get_widget ("cb_noaddfiles")->get_active) {
+    $xml_root->get_widget ("btn_customize_next")->hide;
+    $xml_root->get_widget ("btn_customize_ok")->show;
+    $xml_root->get_widget ("diag_customize")->show();
+
+    # User choose only to add files
+  } elsif ($xml_root->get_widget ("cb_nocustomize")->get_active) {
+    $xml_root->get_widget ("btn_addfiles_previous")->hide;
+    $xml_root->get_widget ("diag_addfiles")->show();
+
+    # User choose to customize disc image and add files
+  } else {
+    # Let's choose the options
+    $xml_root->get_widget ("btn_customize_ok")->hide;
+    $xml_root->get_widget ("btn_customize_next")->show;
+    $xml_root->get_widget ("btn_addfiles_previous")->show;
+    $xml_root->get_widget ("diag_customize")->show();
+  }
+
 }
 
 # Creates the directory that will be used to create the ISO disc image
@@ -1147,166 +1158,191 @@ sub create_tmp_folder {
 
   mkdir  "$tmpDir";
 
-  if ( -e $tmpDir ) {
-    chdir  "$tmpDir";
-
-    if ($movixversion =~ /^eMoviX/) {
-      mkdir "eMoviX";
-      chdir "eMoviX";
-    }
-
-    foreach my $filename (@real_filenames) {
-      system "ln -s $filename ." if ($filename);
-    }
-
-    # Include the movies that were copied into the src/ dir
-    system "ln -s ${srcpath}${src}/* .";
-
-    system "rm -f movix";
-    mkdir  "movix";
-    system "ln -s ${srcpath}${src}movix/* movix";
-
-    system "rm -f isolinux";
-    mkdir  $isolinux;
-    system "cp -r ${srcpath}${src}isolinux/* ${isolinux}";
-    if ($movixversion =~ /^eMoviX/) {
-      system "ln -s `pwd`/boot/kernel/vmlinuz ${isolinux}/vmlinuz";
-    }
-
-    # Remote controls when creating from a eMoviX package.
-    if ($movixversion =~ /^eMoviX/ and
-	-d "${srcpath}${src}movix/remotes" ) {
-      mkdir "remotes";
-      system "ln -s ${srcpath}${src}movix/remotes/* remotes";
-      system "rm -rf movix/remotes";
-    }
-
-    if ( -e "${srcpath}${src}mplayer" ) {
-      system "rm -f mplayer";
-      mkdir  "mplayer";
-      system "ln -s ${srcpath}${src}mplayer/* mplayer";
-    }
-
-    if ( -e $srcpath . "keyboard-i18n/" . $options{'kblayout'} ) {
-      if ($movixversion =~ /^eMoviX/) {
-	# Link the isolinux boot-keymap to the selected keyboard layout
-	system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
-	  "/bootkey.map boot/bootkey.map";
-	# Link the selected shell keymap
-	system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
-	  "/shellkey.map boot/shellkey.map";
-      } else {
-	# Link the isolinux boot-keymap to the selected keyboard layout
-	system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
-	  "/bootkey.map isolinux/bootkey.map";
-	# Link the selected shell keymap
-	system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
-	  "/shellkey.map isolinux/shellkey.map";
-      }
-    }
-
-    # Usefull because the user might not be able to write to the original
-    # isolinux.bin
-    system "rm -f ${isolinux}/isolinux.bin";
-    system "cp ${srcpath}${src}isolinux/isolinux.bin ${isolinux}/isolinux.bin";
-
-    system "rm -f ${isolinux}/*.txt";
-
-    # Translations for eMoviX <= 0.9.0pre1, MoviX and MoviX2
-    if ( -e $srcpath . "boot-messages/" . $options{'boot_help_lang'} ) {
-      system "ln -s ${srcpath}boot-messages/${options{'boot_help_lang'}}/*txt".
-	" ${isolinux}";
-    }
-    # Translations for eMoviX >= 0.9.0rc1
-    if ( -e $srcpath . "translations/" . $options{'boot_help_lang'} ) {
-      mkdir "help";
-      mkdir "mplayer";
-      system "rm -f ${isolinux}/*.msg";
-      system "ln -s ${srcpath}translations/${options{'boot_help_lang'}}/*.{txt,msg}".
-	" ${isolinux}";
-      system "ln -s ${srcpath}translations/${options{'boot_help_lang'}}/*.{sh,man,sub}".
-	" help";
-      system "ln -s ${srcpath}translations/${options{'boot_help_lang'}}/menu.conf".
-	" mplayer";
-    }
-
-
-    if ( -e $srcpath . "mplayer-fonts" ) {
-      my $fontDir = ($movixversion =~ /^eMoviX/) ?
-	"font" : "mplayer/font";
-      system "mkdir -p $fontDir";
-      system "ln -s ${srcpath}mplayer-fonts/$options{'fontset'}/* $fontDir"
-	if ( -e $srcpath . "mplayer-fonts/" . $options{'fontset'} );
-      system "ln -s ${srcpath}mplayer-fonts/*.ttf $fontDir/.";
-      if ($movixversion =~ /^eMoviX/) {
-	# FIXME: User should choose this
-	system "ln -s ${srcpath}mplayer-fonts/Vera.ttf mplayer/subfont.ttf";
-      }
-    }
-
-    if ( defined $options{'bootlabel'} ) {
-      my $isolinuxcfg = "default $options{'bootlabel'}\n";
-
-      open CFG, "${isolinux}/isolinux.cfg";
-      <CFG>;
-      while (<CFG>) {
-	$isolinuxcfg .= $_;
-      }
-      close CFG;
-
-      system "rm -f ${isolinux}/isolinux.cfg";
-      open CFG, "> ${isolinux}/isolinux.cfg";
-      print CFG $isolinuxcfg;
-      close CFG;
-    }
-
-    # Creating the file containing the default [e]MoviX[2] boot parameters
-    my $bootrc = ($movixversion =~ /^eMoviX/) ?
-      "movix/movixrc" : "movix/bootrc";
-
-    open BOOTRC, "> " . $bootrc;
-
-    print BOOTRC "EXTRA-MPLAYER-OPTIONS=$extra_mplayer_options\n"
-      if (defined $extra_mplayer_options && $extra_mplayer_options);
-
-    print BOOTRC "UNWANTED-MPLAYER-OPTIONS=$unwanted_mplayer_options\n"
-      if (defined $unwanted_mplayer_options && $unwanted_mplayer_options);
-
-    print BOOTRC "LOOP=$options{'loop'}\n" if ($options{'loop'} =~ /[0-9]+/);
-    print BOOTRC "SHUT=y\n"     if ($options{'shutdown'} != 0);
-    print BOOTRC "REBOOT=y\n"   if ($options{'reboot'} != 0);
-    print BOOTRC "RANDOM=y\n"   if ($options{'random'} != 0);
-    print BOOTRC "EJECT=y\n"    if ($options{'eject'} != 0);
-    print BOOTRC "DMA=n\n"      if ($options{'nodma'} != 0);
-
-    print BOOTRC "KB=$options{'kblayout'}\n"
-      if ($options{'kblayout'} =~ /[a-z]{2}(\-[a-z]{2})?/);
-
-    print BOOTRC "LANGUAGE=$options{'menu_lang'}\n"
-      if ($options{'menu_lang'} =~ /[a-z]{2}(\-[a-z]{2})?/);
-
-    print BOOTRC "REGION=$options{'tv_region'}\n"
-      unless ($options{'tv_region'} =~ /none/);
-
-    print BOOTRC "REMOTE=$options{'remote'}\n"
-      unless ($options{'remote'} =~ /none/);
-
-    close BOOTRC;
-
-    if ($movixversion =~ /^eMoviX/) {
-      system "rm -f keyboard-i18n mplayer-fonts translations backgrounds";
-      system "rm -f Makefile* {boot,movix,mplayer,remotes}/Makefile*"
-	if (!$installed_emovix);
-    }
-
-    chdir  "$origDir";
-    return $tmpDir;
-  } else {
+  if ( ! -e $tmpDir ) {
     my $badpath = $1 if ( $tmpDir =~ /(.*\/).*$/ );
-    error("$badpath does not exist!");
+
+    if ( ! -w $badpath ) {
+      error("$badpath is not writable");
+    } elsif ( ! -e $badpath ){
+      error("$badpath does not exist!");
+    } else {
+      error("Unknown error when trying to create $tmpDir!");
+    }
+    return;
   }
+
+  chdir  "$tmpDir";
+
+  if ($movixversion =~ /^eMoviX/) {
+    mkdir "eMoviX";
+    chdir "eMoviX";
+  }
+
+  foreach my $filename (@real_filenames) {
+    system "ln -s $filename ." if ($filename);
+  }
+
+  # Include the movies that were copied into the src/ dir
+  system "ln -s ${srcpath}${src}/* .";
+
+  system "rm -f movix";
+  mkdir  "movix";
+  system "ln -s ${srcpath}${src}movix/* movix";
+
+  system "rm -f isolinux";
+  mkdir  $isolinux;
+  system "cp -r ${srcpath}${src}isolinux/* ${isolinux}";
+  if ($movixversion =~ /^eMoviX/) {
+    system "ln -s `pwd`/boot/kernel/vmlinuz ${isolinux}/vmlinuz";
+  }
+
+  # Remote controls when creating from a eMoviX package.
+  if ($movixversion =~ /^eMoviX/ and
+      -d "${srcpath}${src}movix/remotes" ) {
+    mkdir "remotes";
+    system "ln -s ${srcpath}${src}movix/remotes/* remotes";
+    system "rm -rf movix/remotes";
+  }
+
+  if ( -e "${srcpath}${src}mplayer" ) {
+    system "rm -f mplayer";
+    mkdir  "mplayer";
+    system "ln -s ${srcpath}${src}mplayer/* mplayer";
+  }
+
+  if ( -e $srcpath . "keyboard-i18n/" . $options{'kblayout'} ) {
+    if ($movixversion =~ /^eMoviX/) {
+      # Link the isolinux boot-keymap to the selected keyboard layout
+      system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
+	"/bootkey.map boot/bootkey.map";
+      # Link the selected shell keymap
+      system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
+	"/shellkey.map boot/shellkey.map";
+    } else {
+      # Link the isolinux boot-keymap to the selected keyboard layout
+      system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
+	"/bootkey.map isolinux/bootkey.map";
+      # Link the selected shell keymap
+      system "ln -s ${srcpath}keyboard-i18n/${options{'kblayout'}}".
+	"/shellkey.map isolinux/shellkey.map";
+    }
+  }
+
+  # Usefull because the user might not be able to write to the original
+  # isolinux.bin
+  system "rm -f ${isolinux}/isolinux.bin";
+  system "cp ${srcpath}${src}isolinux/isolinux.bin ${isolinux}/isolinux.bin";
+
+  system "rm -f ${isolinux}/*.txt";
+
+  # Translations for eMoviX <= 0.9.0pre1, MoviX and MoviX2
+  if ( -e $srcpath . "boot-messages/" . $options{'boot_help_lang'} ) {
+    system "ln -s ${srcpath}boot-messages/${options{'boot_help_lang'}}/*txt".
+      " ${isolinux}";
+  }
+  # Translations for eMoviX >= 0.9.0rc1
+  if ( -e $srcpath . "translations/" . $options{'boot_help_lang'} ) {
+    mkdir "help";
+    mkdir "mplayer";
+    system "rm -f ${isolinux}/*.msg";
+    system "ln -s ${srcpath}translations/${options{'boot_help_lang'}}/*.{txt,msg}".
+      " ${isolinux}";
+    system "ln -s ${srcpath}translations/${options{'boot_help_lang'}}/*.{sh,man,sub}".
+      " help";
+    system "ln -s ${srcpath}translations/${options{'boot_help_lang'}}/menu.conf".
+      " mplayer";
+  }
+
+
+  if ( -e $srcpath . "mplayer-fonts" ) {
+    my $fontDir = ($movixversion =~ /^eMoviX/) ?
+      "font" : "mplayer/font";
+    system "mkdir -p $fontDir";
+    system "ln -s ${srcpath}mplayer-fonts/$options{'fontset'}/* $fontDir"
+      if ( -e $srcpath . "mplayer-fonts/" . $options{'fontset'} );
+    system "ln -s ${srcpath}mplayer-fonts/*.ttf $fontDir/.";
+    if ($movixversion =~ /^eMoviX/) {
+      # FIXME: User should choose this
+      system "ln -s ${srcpath}mplayer-fonts/Vera.ttf mplayer/subfont.ttf";
+    }
+  }
+
+  create_isolinuxcfg($isolinux);
+
+  # Creating the file containing the default [e]MoviX[2] boot parameters
+  my $bootrc = ($movixversion =~ /^eMoviX/) ?
+    "movix/movixrc" : "movix/bootrc";
+
+  create_bootrc($bootrc);
+
+  if ($movixversion =~ /^eMoviX/) {
+    system "rm -f keyboard-i18n mplayer-fonts translations backgrounds";
+    system "rm -f Makefile* {boot,movix,mplayer,remotes}/Makefile*"
+      if (!$installed_emovix);
+  }
+
+  chdir  "$origDir";
+  return $tmpDir;
 }
 
+
+# Creates the syslinux configuration file
+sub create_isolinuxcfg {
+  my ($isolinux) = shift;
+
+  return if (! defined $options{'bootlabel'} );
+
+  my $isolinuxcfg = "default $options{'bootlabel'}\n";
+
+  open CFG, "${isolinux}/isolinux.cfg";
+  <CFG>;
+  while (<CFG>) {
+    $isolinuxcfg .= $_;
+  }
+  close CFG;
+
+  system "rm -f ${isolinux}/isolinux.cfg";
+  open CFG, "> ${isolinux}/isolinux.cfg";
+  print CFG $isolinuxcfg;
+  close CFG;
+}
+
+
+# Creates the boot configuration file for eMoviX/MoviX/MoviX2
+sub create_bootrc {
+  my $file = shift;
+
+  open BOOTRC, "> " . $file;
+
+  print BOOTRC "EXTRA-MPLAYER-OPTIONS=$extra_mplayer_options\n"
+    if (defined $extra_mplayer_options && $extra_mplayer_options);
+
+  print BOOTRC "UNWANTED-MPLAYER-OPTIONS=$unwanted_mplayer_options\n"
+    if (defined $unwanted_mplayer_options && $unwanted_mplayer_options);
+
+  print BOOTRC "LOOP=$options{'loop'}\n" if ($options{'loop'} =~ /[0-9]+/);
+  print BOOTRC "SHUT=y\n"     if ($options{'shutdown'} != 0);
+  print BOOTRC "REBOOT=y\n"   if ($options{'reboot'} != 0);
+  print BOOTRC "RANDOM=y\n"   if ($options{'random'} != 0);
+  print BOOTRC "EJECT=y\n"    if ($options{'eject'} != 0);
+  print BOOTRC "DMA=n\n"      if ($options{'nodma'} != 0);
+
+  print BOOTRC "KB=$options{'kblayout'}\n"
+    if ($options{'kblayout'} =~ /[a-z]{2}(\-[a-z]{2})?/);
+
+  print BOOTRC "LANGUAGE=$options{'menu_lang'}\n"
+    if ($options{'menu_lang'} =~ /[a-z]{2}(\-[a-z]{2})?/);
+
+  print BOOTRC "REGION=$options{'tv_region'}\n"
+    unless ($options{'tv_region'} =~ /none/);
+
+  print BOOTRC "REMOTE=$options{'remote'}\n"
+    unless ($options{'remote'} =~ /none/);
+
+  close BOOTRC;
+}
+
+
 ####  Command line help
 ######################
 sub help {
